@@ -1,5 +1,5 @@
 package Yancy::Util;
-our $VERSION = '1.068';
+our $VERSION = '1.069';
 # ABSTRACT: Utilities for Yancy
 
 #pod =head1 SYNOPSIS
@@ -40,6 +40,7 @@ use Mojo::JSON::Pointer;
 use Mojo::JSON qw( to_json );
 use Mojo::Util qw( xml_escape );
 use Carp qw( carp );
+use JSON::Validator;
 
 our @EXPORT_OK = qw( load_backend curry currym copy_inline_refs match derp fill_brackets
     is_type order_by is_format json_validator );
@@ -498,7 +499,7 @@ sub derp(@) {
 
 sub json_validator {
     my ( $schema ) = @_;
-    my $v = JSON::Validator::OpenAPI::Mojolicious->new(
+    my $v = JSON::Validator->new(
         # This fixes HTML forms submitting the string "20" not being
         # detected as a number, or the number 1 not being detected as
         # a boolean
@@ -525,7 +526,7 @@ Yancy::Util - Utilities for Yancy
 
 =head1 VERSION
 
-version 1.068
+version 1.069
 
 =head1 SYNOPSIS
 
